import { IPurchasesClient } from "../interfaces/purchases.interfaces";
import { ClientOptions, GetCustomerPurchasesCallback, GetCustomersBulkInfoCallback, GetCustomersBulkInfoParams } from "../types";
import { BaseClient } from "./BaseClient.abstract";
/**
 * class PurchasesClient
 * constructor requires options as
 * {
 *  protocol: 'http',
 *  hostname: 'domain.com',
 *  port: 80,
 *  pathnamePrefix?: '/v2/customers',
 *  clientId?: 'my-client-id',
 *  secret?: 'secret key if exists',
 *  agent?: string
 * }
 */
export declare class PurchasesClient extends BaseClient implements IPurchasesClient {
    /**
     * constructor
     * @param options ClientOptions
     */
    constructor(options: ClientOptions);
    /**
     * Get customer purchases
     * @param applicationUsername : string application-username
     * @param cb : callback method for getting the data.
     * @returns : void
     */
    getCustomerPurchases(applicationUsername: string, cb: GetCustomerPurchasesCallback): void;
    /**
     * Get bulk information about your customers.
     * @param params : GetCustomersBulkInfoParams => limit, skip, applicationUsername
     * @param cb : callback method for getting the data.
     * @returns : void
     */
    getCustomersBulkInfo(params: GetCustomersBulkInfoParams, cb: GetCustomersBulkInfoCallback): void;
}
